<?php
// Version: 2.0 rc3; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0 rc3';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as opposed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;

	/* Set the following variable to true if this theme requires the optional theme strings file to be loaded. */
	$settings['require_theme_strings'] = true;



}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '>
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title_html_safe'], '" />
	<meta name="keywords" content="', $context['meta_keywords'], '" />
	<title>', $context['page_title_html_safe'], '</title>';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex" />';

	// Present a canonical url for search engines to prevent duplicate content in their indices.
	if (!empty($context['canonical_url']))
		echo '
	<link rel="canonical" href="', $context['canonical_url'], '" />';

	// The ?rc3 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/index', $context['theme_variant'], '.css?rc3" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/print.css?rc3" media="print" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="', $scripturl, '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['rss'], '" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0" />';

	// Some browsers need an extra stylesheet due to bugs/compatibility issues.
	foreach (array('ie7', 'ie6', 'firefox', 'webkit') as $cssfix)
		if ($context['browser']['is_' . $cssfix])
			echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/', $cssfix, '.css" />';

	// RTL languages require an additional stylesheet.
	if ($context['right_to_left'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/rtl.css" />';

	echo '
	<script type="text/javascript" src="', $settings['theme_url'], '/bin/jquery.js"></script>
	<script type="text/javascript" src="', $settings['theme_url'], '/bin/interface.js"></script>
	<script type="text/javascript" src="', $settings['default_theme_url'], '/scripts/script.js?rc3"></script>
	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/theme.js?rc3"></script>
	
  <script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
	$(document).ready(
		function()
		{
			$("#dock").Fisheye(
				{
					maxWidth: 80,
					items: "a",
					itemsText: "span",
					container: ".dock-container",
					itemWidth: 40,
					proximity: 90,
					halign : "center"
				}
			)
		}
	);
  	// ]]></script>
	
	<script type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		var fPmPopup = function ()
		{
			if (confirm("' . $txt['show_personal_messages'] . '"))
				window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");
		}
		addLoadEvent(fPmPopup);' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";
	// ]]></script>';

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'];

	echo '
</head>
<body>';
}

function template_body_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo !empty($settings['forum_width']) ? '
<div id="wrapper" style="width: ' . $settings['forum_width'] . '">' : '', '
';

		// Show some statistics if stat info is off.
	if ($settings['show_stats_index'])
		{
			echo '
	<div  class="windowbg" align="center" style="font-size: 6.5pt;">';

	echo '
		', $txt['members'], ': ', $context['common_stats']['total_members'], ' &nbsp;&#8226;&nbsp; ', $txt['posts_made'], ': ', $context['common_stats']['total_posts'], ' &nbsp;&#8226;&nbsp; ', $txt['topics'], ': ', $context['common_stats']['total_topics'], '
		', ($settings['show_latest_member'] ? ' &nbsp;&#8226;&nbsp; ' . $txt['welcome_member'] . ' <b>' . $context['common_stats']['latest_member']['link'] . '</b>' . $txt['newest_member'] : '') , '
	</div>';
		}
	
template_dock_menu ();

	// show the menu
	echo '
				<div class="gmhead-l">
					<div class="gmhead-r">
					    <div class="gmheader">';
						
			if ($context['user']['is_logged'])
			{

	if (!empty($context['user']['avatar']))
		echo '
				<div id="userareaavatarleft">', $context['user']['avatar']['image'], '</div>
				<div id="userareaavatarright">', $context['user']['avatar']['image'], '</div>';

			}
	echo '
		<div id="logo">';
	if (empty($settings['header_logo_url']))
		 echo $context['forum_name_html_safe'];
	else
		echo ' <a href="'.$scripturl.'" title=""><img  src="', $settings['header_logo_url'], '" alt="" /></a>
				';

//	if (empty($settings['header_logo_url']))
//	{
//	 echo ' <div style="font-size: 0pt;">';
//	 	 		echo ' <a href="'.$scripturl.'" title=""><img src="', $settings['theme_url'], '/header.png" alt="', $context['forum_name_html_safe'], '"/></a>';
//
//		echo  '</div>';
//	}
//	else
//		echo ' <a href="'.$scripturl.'" title=""><img  src="', $settings['header_logo_url'], '" alt="', $context['forum_name_html_safe'], '" /></a>
//				';
	echo ' </div>'; // logo

	
	echo '
					</div>
				</div> ';
						
	echo '
				</div>';
	// end of header shortie
	echo'				<table class="gmtitlebg2" width="100%">
						<tr align="center">
						<td>';
						template_userarea();
//						template_menu();

	echo' 				</td>
						</tr>
						</table>';

	echo '
			<div class="clearfix">
			<form class="floatright" id="search_form" action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">
				<a href="', $scripturl, '?action=search;advanced" title="', $txt['search_advanced'], '"><img id="advsearch" src="'.$settings['images_url'].'/filter.gif" align="middle" alt="', $txt['search_advanced'], '" /></a>
				<input type="text" name="search" value="" style="width: 190px;" />&nbsp;
				<input type="submit" name="submit" value="', $txt['search'], '" style="width: 11ex;" />
				<input type="hidden" name="advanced" value="0" />';

	// Search within current topic?
	if (!empty($context['current_topic']))
		echo '
				<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
	// If we're on a certain board, limit it to this board ;).
	elseif (!empty($context['current_board']))
		echo '
				<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';
	echo '
			</form>';
	// Show a random news item? (or you could pick one from news_lines...)
	if (!empty($settings['enable_news']))
		echo '
			<div id="random_news"><h3>', $txt['news'], ':</h3><p>', $context['random_news_line'], '</p></div>';
	else
		echo '
			<div id="random_news"><h3><p></p></h3></div>';
	echo '
		</div>';

	echo '
			<br class="clear" />';

		// Show the navigation tree.
		theme_linktree();


	// The main content should go here.
	echo '
	<div id="content_section"><div class="frame">
		<div id="main_content_section">';
}

function template_body_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
		</div>
	</div></div>';

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '
	<div id="footer_section"><div class="frame"> ';
template_copy();
	echo '
	</div></div>';
}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo !empty($settings['forum_width']) ? '
</div>' : '', '
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree($force_show = false)
{
	global $context, $settings, $options, $shown_linktree;

	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	// Reverse the linktree in right to left mode.
	if ($context['right_to_left'])
		$context['linktree'] = array_reverse($context['linktree'], true);

	echo '
	<div class="navigate_section">
		<ul>';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		echo '
			<li', ($link_num == count($context['linktree']) - 1) ? ' class="last"' : '', '>';

		// Don't show a separator for the last one (RTL mode)
		if ($link_num != count($context['linktree']) - 1 && $context['right_to_left'])
			echo '&#171;&nbsp;';

			// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo $settings['linktree_link'] && isset($tree['url']) ? '
				<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>' : '<span>' . $tree['name'] .'</span>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1 && !$context['right_to_left'])
			echo '&nbsp;&#187;';

		echo '
			</li>';
	}
	echo '
		</ul>
	</div>';

	$shown_linktree = true;
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
		<div id="main_menu">
			<ul class="dropmenu" id="menu_nav">';

	foreach ($context['menu_buttons'] as $act => $button)
	{
		echo '
				<li id="button_', $act, '">
					<a class="', $button['active_button'] ? 'active ' : '', 'firstlevel" href="', $button['href'], '"', isset($button['target']) ? ' target="' . $button['target'] . '"' : '', '>
						<span class="', isset($button['is_last']) ? 'last ' : '', 'firstlevel">', $button['title'], '</span>
					</a>';
		if (!empty($button['sub_buttons']))
		{
			echo '
					<ul>';

			foreach ($button['sub_buttons'] as $childbutton)
			{
				echo '
						<li>
							<a href="', $childbutton['href'], '"', isset($childbutton['target']) ? ' target="' . $childbutton['target'] . '"' : '', '>
								<span', isset($childbutton['is_last']) ? ' class="last"' : '', '>', $childbutton['title'], !empty($childbutton['sub_buttons']) ? '...' : '', '</span>
							</a>';
				// 3rd level menus :)
				if (!empty($childbutton['sub_buttons']))
				{
					echo '
							<ul>';

					foreach ($childbutton['sub_buttons'] as $grandchildbutton)
						echo '
								<li>
									<a', $grandchildbutton['active_button'] ? ' class="active"' : '', ' href="', $grandchildbutton['href'], '"', isset($grandchildbutton['target']) ? ' target="' . $grandchildbutton['target'] . '"' : '', '>
										<span', isset($grandchildbutton['is_last']) ? ' class="last"' : '', '>', $grandchildbutton['title'], '</span>
									</a>
								</li>';

					echo '
						</ul>';
				}

				echo '
						</li>';
			}
			echo '
					</ul>';
		}
		echo '
				</li>';
	}

	echo '
			</ul>
		</div>';
}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $strip_options = array())
{
	global $settings, $context, $txt, $scripturl;

	if (!is_array($strip_options))
		$strip_options = array();

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
	{
		if (!isset($value['test']) || !empty($context[$value['test']]))
			$buttons[] = '<a ' . (isset($value['active']) ? 'class="active" ' : '') . 'href="' . $value['url'] . '" ' . (isset($value['custom']) ? $value['custom'] : '') . '><span>' . $txt[$value['text']] . '</span></a>';
	}

	// No buttons? No button strip either.
	if (empty($buttons))
		return;

	// Make the last one, as easy as possible.
	$buttons[count($buttons) - 1] = str_replace('<span>', '<span class="last">', $buttons[count($buttons) - 1]);

	echo '
		<div class="buttonlist', !empty($direction) ? ' align_' . $direction : '', '"', (empty($buttons) ? ' style="display: none;"' : ''), (!empty($strip_options['id']) ? ' id="' . $strip_options['id'] . '"': ''), '>
			<ul>
				<li>', implode('</li><li>', $buttons), '</li>
			</ul>
		</div>';
}
function template_gmsearch ()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;
	echo '
			<div class="clear"><div id="sbox">
			    <form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">
			    <input class="inputbox" type="text" name="search" value="', $txt['search'], '....." onfocus="this.value = \'\';" onblur="if(this.value==\'\') this.value=\'', $txt['search'], '...\';" />';

			// Search within current topic?
			if (!empty($context['current_topic']))
			echo '
				<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
	
			// If we're on a certain board, limit it to this board ;).
			elseif (!empty($context['current_board']))
			echo '
				<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';

			echo '
			      </form></div></div>';
}
function template_copy()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;
	


	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo ' 
	
	<table width="100%" align="center">
<tr>
<td width="50%" class="copycolour" style="text-align: center; ">
			<ul class="smalltext">
			<li class="smalltext">', theme_copyright(), '</li>
			</ul>
			<ul>
			<li><a id="button_xhtml" href="http://validator.w3.org/check/referer" target="_blank" class="new_win" title="', $txt['valid_xhtml'], '"><span>XHTML</span></a>&nbsp;<a id="button_rss" href="', $scripturl , '?type=rss;action=.xml" class="new_win"><span>RSS</span></a>&nbsp;<a id="button_wap2" href="', $scripturl , '?wap2" class="new_win"><span>WAP2</span>  </a></li>
		</ul>

	</td>
	<td height ="70px" width="50%" style="text-align: center;">
	<div class="smalltext"><a href="http://graphicsmayhem.com">The PlayRoom Designed By Shortie 2010</a></div>';
	if ($context['show_load_time'])
	{
		echo '
		<div class="smalltext" id="show_loadtime">', $txt['page_created'], $context['load_time'], $txt['seconds_with'], $context['load_queries'], $txt['queries'], '</div>';
	}
echo '	</td>
	</tr>
	</table>';
}
function template_userarea()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;
	
echo '								<div id="userarea" >';
			if ($context['user']['is_logged'])
			{
//	if (!empty($context['user']['avatar']))
	//		echo '
	//		<div id="userareaavatar">', $context['user']['avatar']['image'], '</div>';
				echo '
							<b>', $txt['hello_member_ndt'], ' ', $context['user']['name'], '</b> &nbsp;';
				// Only tell them about their messages if they can read their messages!
				if ($context['allow_pm'])
					echo $txt['msg_alert_you_have'], ' <a href="', $scripturl, '?action=pm">', $context['user']['messages'], ' ', $context['user']['messages'] != 1 ? $txt['msg_alert_messages'] : $txt['message_lowercase'], '</a>', $txt['newmessages4'], ' ', $context['user']['unread_messages'], ' ', $context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1'] , '. &nbsp;[';
				echo '
								<a href="', $scripturl, '?action=unread">',$txt['show_unread_since_visit'],'</a>&nbsp;/
								<a href="', $scripturl, '?action=unreadreplies">',$txt['show_all_unread_replies'],'</a>&nbsp;/
								<a href="', $scripturl, '?action=profile;area=showposts">',$txt['ownposts2'],'</a>]<br />
								', $context['current_time'],'';
		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '
					<div class="notice">', $txt['maintain_mode_on'], '</div>';
		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '
					', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=admin;area=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '<br />';

		// Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '
					<br />', $txt['totalTimeLogged1'];

			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];

			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '
					';
		}
		if (!empty($context['open_mod_reports']) && $context['show_open_reports'])
			echo '
					<a href="', $scripturl, '?action=moderate;area=reports">', sprintf($txt['mod_reports_waiting'], $context['open_mod_reports']), '</a><br />';
			}
			// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
	else
	{
		echo '
				<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/sha1.js"></script>
				<form class="smalltext" id="guest_form" action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" ', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
					' , $txt['login_or_register'], '<br />
					<input type="text" name="user" size="10" />
					<input type="password" name="passwrd" size="10" />
					<select name="cookielength">
						<option value="60">', $txt['one_hour'], '</option>
						<option value="1440">', $txt['one_day'], '</option>
						<option value="10080">', $txt['one_week'], '</option>
						<option value="43200">', $txt['one_month'], '</option>
						<option value="-1" selected="selected">', $txt['forever'], '</option>
					</select>
					<input type="submit" value="', $txt['login'], '" /><br />
					', $txt['quick_login_dec'];

		if (!empty($modSettings['enableOpenID']))
			echo'
					<br />
					<input type="text" name="openid_url" id="openid_url" size="25" class="openid_login" />';

		echo '
					<input type="hidden" name="hash_passwrd" value="" />
				</form>';
	}
					echo '
						</div>';
}

function template_the_menu ()
{
	echo ' <table class="menu-wrapper"><tr><td> ';
	template_menu();
	echo '</td></tr></table>';
}

function template_dock_menu ()
{
	
		global $context, $modSettings, $user_info, $settings, $options, $scripturl, $txt;

echo ' <table class="dock-wrapper"><tr><td> ';

//			if ($context['user']['is_logged'])
//			{
//	template_colour_swapper();	
//			}
echo '
<div class="dock" id="dock">
  <div class="dock-container">';
echo '
	  <a class="dock-item" href="', $scripturl, '" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/home.png" alt="' . $txt['gmhome'] . '" /><span>' . $txt['gmhome'] . '</span></a> ';

echo '
	  <a class="dock-item" href="', $scripturl, '?action=help" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/help.png" alt="' . $txt['gmhelp'] . '" /><span>' . $txt['gmhelp'] . '</span></a> ';

echo '
	  <a class="dock-item" href="', $scripturl, '?action=search" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/search.png" alt="' . $txt['gmsearch'] . '" /><span>' . $txt['gmsearch'] . '</span></a> ';

if ($context['allow_edit_profile'])
				echo '<a class="dock-item" href="', $scripturl, '?action=profile" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/profile.png" alt="' . $txt['gmprofile'] .'" /><span>' . $txt['gmprofile'], '</span></a>';

if ($context['allow_pm'])
{
	if ( $context['user']['unread_messages'] >= 1 )
	{
	echo '<a class="dock-item" href="', $scripturl, '?action=pm" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/pmsome.png" alt="' . $txt['gmpmsome'] .'" /><span>' . $txt['gmpmsome'], '</span></a>';
} 
else {
	echo '<a class="dock-item" href="', $scripturl, '?action=pm" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/pm.png" alt="' . $txt['gmpmnone'] .'" /><span>' . $txt['gmpmnone'], '</span></a>';
}
}

		if ($context['allow_memberlist'])
				echo '<a class="dock-item" href="', $scripturl, '?action=mlist" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/members.png" alt="' . $txt['gmmembers'] .'" /><span>' . $txt['gmmembers'], '</span></a>';

if ($context['allow_calendar'])
				echo '<a class="dock-item" href="', $scripturl, '?action=calendar" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/cal.png" alt="' . $txt['gmcal'] .'" /><span>' . $txt['gmcal'], '</span></a>';

//if ($user_info['is_guest'] ? !empty($modSettings['contact_form_enable_guest_access']) : !empty($modSettings['contact_form_enable_member_access']))
//				echo '<a class="dock-item" href="', $scripturl, '?action=contact" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/contact.png" alt="' . $txt['gmcontact'] .'" /><span>' . $txt['gmcontact'], '</span></a>';
 
if ($context['allow_moderation_center'])
				echo '<a class="dock-item" href="', $scripturl, '?action=moderate" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/moderate.png" alt="' . $txt['gmmod'] .'" /><span>' . $txt['gmmod'], '</span></a>';
        
		if ($context['allow_admin'])
				echo '<a class="dock-item" href="', $scripturl, '?action=admin" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/admin.png" alt="' . $txt['gmadmin'] .'" /><span>' . $txt['gmadmin'], '</span></a>';

		if ($context['user']['is_logged'])
				echo '<a class="dock-item" href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/logout.png" alt="' . $txt['gmlogout'] . '" /><span>' . $txt['gmlogout'], '</span></a>';
                
		 if ($context['user']['is_guest'])		  
				echo '<a class="dock-item" href="', $scripturl, '?action=login" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/login.png" alt="' . $txt['gmlogin'] . '" /><span>' . $txt['gmlogin'], '</span></a>';
                
		  if ($context['user']['is_guest'])	
				echo '<a class="dock-item" href="', $scripturl, '?action=register" ><img src="' . $settings['theme_url'] . '/images/dicons/dicons', $context['theme_variant'], '/reg.png" alt="' . $txt['gmreg'] . '" /><span>' . $txt['gmreg'], '</span></a>';
echo '
  </div>
</div>';
echo '</td></tr></table>';

}

function template_colour_swapper()
{

		global $context, $modSettings, $user_info, $settings, $options, $scripturl, $txt;

echo '

<div class="colour_menu">
        <ul class="select">
          <li class="line"><a href="#nogo"><img src="', $settings['theme_url'], '/images/dicons/themes.png" alt="Themes" width="90" height="25"/></a>
            <ul class="sub">';
echo '			  <li><a href="' . $scripturl . '?variant=darkblue"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_darkblue/colour_dot_darkblue.png" alt="Dark Blue" width="25" height="25"/></a></li>';
echo '              <li><a href="' . $scripturl . '?variant=framemaker"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_framemaker/colour_dot_framemaker.png" alt="Framemaker" width="25" height="25"/></a></li>';
echo '              <li><a href="' . $scripturl . '?variant=indesign"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_indesign/colour_dot_indesign.png" alt="Indesign" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=darkpurple"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_darkpurple/colour_dot_darkpurple.png" alt="Dark Purple" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=soundbooth"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_soundbooth/colour_dot_soundbooth.png" alt="Soundbooth" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=lightroom"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_lightroom/colour_dot_lightroom.png" alt="Lightroom" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=darkgray"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_darkgray/colour_dot_darkgray.png" alt="Darkgray" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=drama"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_drama/colour_dot_drama.png" alt="Drama" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=game"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_game/colour_dot_game.png" alt="Game" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=horror"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_horror/colour_dot_horror.png" alt="Horror" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=kids"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_kids/colour_dot_kids.png" alt="Kids" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=music"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_music/colour_dot_music.png" alt="Music" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=scifi"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_scifi/colour_dot_scifi.png" alt="Scifi" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=soap"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_soap/colour_dot_soap.png" alt="Soap" width="25" height="25"/></a></li>';
echo '               <li><a href="' . $scripturl . '?variant=sports"><img src="'. $settings['theme_url'] .  '/images/dicons/dicons_sports/colour_dot_sports.png" alt="Sports" width="25" height="25"/></a></li>';
echo'
            </ul>
          </li>

        </ul>
      </div>
';

}
?>